PROGRAM HasXMS;
(*

        Does:       Checks to see if your station has Extended memory
        Language:   Turbo Pascal
        Programmer: Russ Bellew
        Created:    2 May 95 (based upon HasEms, from 1992)

        Requires:
          Compiler:
            Borland's Turbo Pascal ver 6.0;
          Libraries:
            OpString.tpu, OpXms.tpu, from TurboPower Software's Object
                         Professional;
          Runtime Environment:
            MS-DOS;


        Revisions:

*)

{$DEFINE production}

{$IFDEF production} {$D-} {$R-} {$L-} {$S-} {$ENDIF}


USES Crt, OpXMS, OpString;

CONST
  ProgName = 'HasXMS';
  Version = '1.00';
  Date = 'May 1, 1995';
  Copyright = 'Copyright (c) 1995 by Radiodetection Corp. & Russ Bellew';


VAR
  VerboseWanted,
  Quiet,
  ClearScreenWanted,
  PauseDisplayWanted : Boolean;
  PauseSecs          : LongInt;

  MinXmsWanted       : LongInt;       { This is how much XMS user wants }
  TotalFree,
  LargestBlock       : Word;
  XmsQueryResult     : Byte;



Procedure GetParameters;
{ get command line parameters used to start this program }
var
  i    : byte;
  s    : string;
  Numeric : boolean;
begin
  ClearScreenWanted  := False;
  VerboseWanted      := False;
  Quiet              := False;
  PauseDisplayWanted := False;
  Numeric            := False;
  PauseSecs          := 0;

  Numeric := Str2long(ParamStr(1), MinXMSWanted );
  if not Numeric then MinXMSWanted := 0;

  for i := 1 to ParamCount do begin
    s := StUpCase(ParamStr(i));
    if (s[1] = '/') or (s[1] = '-') then Delete(s, 1, 1);

    case s[1] of
      'C'     : ClearScreenWanted := True;
      'V'     : VerboseWanted := True;
      'P','W' : begin
                  PauseDisplayWanted := True;
                  Numeric := Str2long(ParamStr(i + 1), PauseSecs );
                  if not Numeric then PauseSecs := 0;
                end; { 'P','W'... }
      'Q'     : Quiet := True;
      'H','?' : begin
                  WriteLn(ProgName,'   ',Version, '  ',Date);
                  WriteLn(Copyright);
                  WriteLn;
                  WriteLn('This program tells you if you have at least a certain amount of extended memory');
                  WriteLn('free.  It returns a DOS errorlevel of 1 if the answer is YES, or a DOS');
                  WriteLn('errorlevel of 0 if the answer is NO.  It returns an errorlevel of 255 if an XMS');
                  WriteLn('hardware or software failure is detected.  Use the returned errorlevel in your');
                  WriteLn('batch file to determine whether to run a program that assumes the existence of');
                  WriteLn('extended memory.');
                  WriteLn;
                  WriteLn('Pass the amount of extended memory that you want to check for (in kilobytes)');
                  WriteLn('on the command line.  Other command line options: QUIET - disable display');
                  WriteLn('                                                  CLEAR - clear screen');
                  WriteLn;
                  WriteLn('Example : HASXMS 1024');
                  WriteLn('This will return a DOS errorlevel of 1 if you have at least 1024k (1 meg) of');
                  WriteLn('   extended memory available, or a DOS errorlevel of 0 if you don''t.');
                  WriteLn;
                  WriteLn;
                  WriteLn('Use this program as you like, at no cost.              All Rights Reserved.');
                  WriteLn('                 Radiodetection Corp.   Phone: 201 848-8070');
                  WriteLn(' "Manufacturer of the world''s best buried cable and pipe locating equipment"');
                  WriteLn('                   35 Whitney Road, Mahwah, NJ  07430 USA');
                  Halt(0);
                end; { 'H','?' : begin }
    end; { case s[1] of }

  end; { for i = 1 to paramcount }
end;


Begin { program }
  { Use BIOS for screen writes }
  Close(Output);
  Assign(Output,'');
  Rewrite(Output);

  GetParameters;
  if ClearScreenWanted then ClrScr;
  if not Quiet then
    begin
      WriteLn(ProgName,' ',Version,' ',Copyright);
      WriteLn;
    end;

  if not OpXms.XmsInstalled then
    begin
      if not Quiet then WriteLn('No extended memory manager is installed.');
      Halt(0);
    end;

  XmsQueryResult := OpXMS.QueryFreeExtMem(TotalFree, LargestBlock);
  Case XmsQueryResult of
    $00 : ; { no error detected }
    $80 : begin
            WriteLn('Xms "query free" function is not implemented.');
            Halt(255);
          end;
    $81 : WriteLn('Vdisk detected.');
    $A0 : WriteLn('All extended memory is allocated.');
  else
    begin
      WriteLn('Unknown Xms query result.');
      Halt(255);
    end;
  end; { case }

  if not Quiet then
    begin
      WriteLn(TotalFree, 'k of extended memory available.');
      WriteLn(LargestBlock, 'k is largest available block.');
    end;
  if LargestBlock >= MinXmsWanted then
    Halt(1)
  else
    Halt(0);

end. { program }
